@@ -1,4 +1,4 @@
-// $Id: vlimit.c,v 1.7 2004/01/21 01:27:01 ensc Exp $
+// $Id: vlimit.c,v 1.1.2.3 2004/02/20 19:35:50 ensc Exp $
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -29,7 +29,7 @@
 #include "compat.h"
 
 #include "vserver.h"
-#include "internal.h"
+#include "vserver-internal.h"
 
 #include <getopt.h>
 #include <string.h>
@@ -37,7 +37,6 @@
 #include <assert.h>
 #include <stdbool.h>
 #include <stdio.h>
-#include <stdlib.h>
 
 #define VERSION_COPYRIGHT_DISCLAIMER
 
@@ -75,7 +74,7 @@ showHelp(int fd, char const *cmd, int res)
   WRITE_MSG(fd, "Usage:  ");
   WRITE_STR(fd, cmd);
   WRITE_MSG(fd,
-	    " [-c <ctx>] [-a|--all] [-MSH  --<nr> <value>]*\n"
+	    " -c <xid> [-a|--all] [-MSH  --<nr> <value>]*\n"
 	    "Please report bugs to " PACKAGE_BUGREPORT "\n");
   exit(res);
 }
@@ -102,9 +101,11 @@ appendLimit(char *ptr, bool do_it, vc_limit_t lim)
       ptr += 3;
     }
     else {
-      memcpy(ptr, "0x", 2); ptr += 2;
-      
-      ptr += utilvserver_fmt_xuint64(ptr, lim);
+      memcpy(ptr, "0x", 2);
+      ptr += 2;
+
+      ptr += utilvserver_uint2str(ptr, 20, (lim>>32),      16);
+      ptr += utilvserver_uint2str(ptr, 20, lim&0xffffffff, 16);
       *ptr = ' ';
     }
   }
@@ -122,9 +123,9 @@ showAll(int ctx)
   struct vc_rlimit_mask	mask;
   size_t		i;
 
-  if (vc_get_rlimit_mask(-2, &mask)==-1) {
+  if (vc_get_rlimit_mask(ctx, &mask)==-1) {
     perror("vc_get_rlimit_mask()");
-    //exit(1);
+    exit(1);
   }
 
   for (i=0; i<32; ++i) {
@@ -132,13 +133,14 @@ showAll(int ctx)
     struct vc_rlimit	limit;
     char		buf[100], *ptr=buf;
     
+    if (((mask.min|mask.soft|mask.hard) & bitmask)==0) continue;
     if (vc_get_rlimit(ctx, i, &limit)==-1) {
       perror("vc_get_rlimit()");
       //continue;
     }
 
     memset(buf, ' ', sizeof buf);
-    ptr += utilvserver_fmt_uint(ptr, i);
+    ptr += utilvserver_uint2str(ptr, 100, i, 10);
     *ptr = ' ';
 
     ptr  = appendLimit(buf+10, mask.min &bitmask, limit.min);
@@ -151,7 +153,7 @@ showAll(int ctx)
 }
 
 static void
-setLimits(int ctx, struct vc_rlimit const limits[], uint32_t mask)
+  setLimits(int ctx, struct vc_rlimit const limits[], uint32_t mask)
 {
   size_t		i;
   for (i=0; i<32; ++i) {
@@ -169,7 +171,7 @@ int main (int argc, char *argv[])
   int			set_mask = 0;
   struct vc_rlimit	limits[32];
   bool			show_all = false;
-  xid_t			ctx      = VC_SAMECTX;
+  xid_t			ctx      = VC_NOCTX;
 
   {
     size_t		i;
@@ -193,7 +195,7 @@ int main (int argc, char *argv[])
 
       if (set_mask & 1) limits[id].min  = val;
       if (set_mask & 2) limits[id].soft = val;
-      if (set_mask & 4) limits[id].hard = val;
+      if (set_mask & 4) limits[id].soft = val;
 
       lim_mask |= (1<<id);
       set_mask  = 0;
@@ -223,6 +225,11 @@ int main (int argc, char *argv[])
     }
   }
 
+  if (ctx==VC_NOCTX) {
+    WRITE_MSG(2, "No context specified; try '--help' for more information\n");
+    return EXIT_FAILURE;
+  }
+
   setLimits(ctx, limits, lim_mask);
   if (show_all) showAll(ctx);
 
